Module errors

Module errors 

Core error types module for filthy-rich.

The primary error here is PresenceError which can either be PresenceClientError or PresenceRunnerError. These two types of errors host their own subset of errors which can be applicable for many different scenarios.

Enums

ActivitySpecBuildError
Error which happens if building a crate::types::ActivitySpec fails via crate::types::ActivityBuilder::build.
DisconnectReason
Details about why the RPC connection was lost.
PresenceClientError
Points to errors specifically related to crate::PresenceClient.
PresenceError
Core convenience error type for usage with all types of filthy-rich operations, including crate::PresenceRunner and crate::PresenceClient.
PresenceRunnerError
Points to errors specifically related to crate::PresenceRunner.