macro_rules! nf {
($name:ident, $doc:expr, $param:ident) => { ... };
}Expand description
Generates a function $name which takes a $param and sets the
$name field of a struct to be a None-filtered String.
macro_rules! nf {
($name:ident, $doc:expr, $param:ident) => { ... };
}Generates a function $name which takes a $param and sets the
$name field of a struct to be a None-filtered String.