DiscordIPCSync

Struct DiscordIPCSync 

pub struct DiscordIPCSync { /* private fields */ }
Blocking implementation of DiscordIPC.

Implementations

Source

impl DiscordIPCSync

pub fn new(client_id: &str) -> Result<Self>

Creates a new Discord IPC client instance.

Examples found in repository?
examples/indefinite-sync.rs (line 4)
3fn main() {
4    let mut client = DiscordIPCSync::new("1463450870480900160")
5        .unwrap()
6        .on_ready(|data| println!("Connected to user: {}", data.user.username));
7
8    client.run(true).unwrap();
9
10    let activity = Activity::new().details("this runs forever").build();
11
12    client.set_activity(activity).unwrap();
13    client.wait().unwrap();
14}
More examples
Hide additional examples
examples/timed-sync.rs (line 6)
5fn main() {
6    let mut client = DiscordIPCSync::new("1463450870480900160")
7        .unwrap()
8        .on_ready(|data| println!("Connected to user: {}", data.user.username));
9
10    // create activities for later use
11    let activity_1 = Activity::new()
12        .details("this runs")
13        .state("for ten seconds")
14        .build();
15    let activity_2 = Activity::new()
16        .details("believe it")
17        .state("or not")
18        .build();
19    let close_activity = Activity::new()
20        .details("closing presence in...")
21        .duration(Duration::from_secs(5))
22        .build();
23
24    // first run
25    client.run(true).unwrap();
26
27    client.set_activity(activity_1).unwrap();
28    sleep(Duration::from_secs(5));
29    client.set_activity(activity_2).unwrap();
30    sleep(Duration::from_secs(5));
31    client.set_activity(close_activity).unwrap();
32    sleep(Duration::from_secs(5));
33}
pub fn on_ready<F: Fn(ReadyData) + Send + Sync + 'static>(self, f: F) -> Self

Run a particular closure after receiving the READY event from the local Discord IPC server.

Examples found in repository?
examples/indefinite-sync.rs (line 6)
3fn main() {
4    let mut client = DiscordIPCSync::new("1463450870480900160")
5        .unwrap()
6        .on_ready(|data| println!("Connected to user: {}", data.user.username));
7
8    client.run(true).unwrap();
9
10    let activity = Activity::new().details("this runs forever").build();
11
12    client.set_activity(activity).unwrap();
13    client.wait().unwrap();
14}
More examples
Hide additional examples
examples/timed-sync.rs (line 8)
5fn main() {
6    let mut client = DiscordIPCSync::new("1463450870480900160")
7        .unwrap()
8        .on_ready(|data| println!("Connected to user: {}", data.user.username));
9
10    // create activities for later use
11    let activity_1 = Activity::new()
12        .details("this runs")
13        .state("for ten seconds")
14        .build();
15    let activity_2 = Activity::new()
16        .details("believe it")
17        .state("or not")
18        .build();
19    let close_activity = Activity::new()
20        .details("closing presence in...")
21        .duration(Duration::from_secs(5))
22        .build();
23
24    // first run
25    client.run(true).unwrap();
26
27    client.set_activity(activity_1).unwrap();
28    sleep(Duration::from_secs(5));
29    client.set_activity(activity_2).unwrap();
30    sleep(Duration::from_secs(5));
31    client.set_activity(close_activity).unwrap();
32    sleep(Duration::from_secs(5));
33}
pub fn client_id(&self) -> String

The Discord client ID that has been used to initialize this IPC client instance.

pub fn run(&mut self, wait_for_ready: bool) -> Result<()>

Run the client. Must be called before any DiscordIPCSync::set_activity calls.

Examples found in repository?
examples/indefinite-sync.rs (line 8)
3fn main() {
4    let mut client = DiscordIPCSync::new("1463450870480900160")
5        .unwrap()
6        .on_ready(|data| println!("Connected to user: {}", data.user.username));
7
8    client.run(true).unwrap();
9
10    let activity = Activity::new().details("this runs forever").build();
11
12    client.set_activity(activity).unwrap();
13    client.wait().unwrap();
14}
More examples
Hide additional examples
examples/timed-sync.rs (line 25)
5fn main() {
6    let mut client = DiscordIPCSync::new("1463450870480900160")
7        .unwrap()
8        .on_ready(|data| println!("Connected to user: {}", data.user.username));
9
10    // create activities for later use
11    let activity_1 = Activity::new()
12        .details("this runs")
13        .state("for ten seconds")
14        .build();
15    let activity_2 = Activity::new()
16        .details("believe it")
17        .state("or not")
18        .build();
19    let close_activity = Activity::new()
20        .details("closing presence in...")
21        .duration(Duration::from_secs(5))
22        .build();
23
24    // first run
25    client.run(true).unwrap();
26
27    client.set_activity(activity_1).unwrap();
28    sleep(Duration::from_secs(5));
29    client.set_activity(activity_2).unwrap();
30    sleep(Duration::from_secs(5));
31    client.set_activity(close_activity).unwrap();
32    sleep(Duration::from_secs(5));
33}
pub fn wait(&mut self) -> Result<()>

Waits for the IPC task to finish. DiscordIPCSync::run must be called to spawn it in the first place.

Examples found in repository?
examples/indefinite-sync.rs (line 13)
3fn main() {
4    let mut client = DiscordIPCSync::new("1463450870480900160")
5        .unwrap()
6        .on_ready(|data| println!("Connected to user: {}", data.user.username));
7
8    client.run(true).unwrap();
9
10    let activity = Activity::new().details("this runs forever").build();
11
12    client.set_activity(activity).unwrap();
13    client.wait().unwrap();
14}
pub fn is_running(&self) -> bool

Checks whether the task is running through the internal atomic indicator flag.

pub fn set_activity(&self, activity: Activity) -> Result<()>

Sets/updates the Discord Rich presence activity. DiscordIPCSync::run must be executed prior to calling this.

Examples found in repository?
examples/indefinite-sync.rs (line 12)
3fn main() {
4    let mut client = DiscordIPCSync::new("1463450870480900160")
5        .unwrap()
6        .on_ready(|data| println!("Connected to user: {}", data.user.username));
7
8    client.run(true).unwrap();
9
10    let activity = Activity::new().details("this runs forever").build();
11
12    client.set_activity(activity).unwrap();
13    client.wait().unwrap();
14}
More examples
Hide additional examples
examples/timed-sync.rs (line 27)
5fn main() {
6    let mut client = DiscordIPCSync::new("1463450870480900160")
7        .unwrap()
8        .on_ready(|data| println!("Connected to user: {}", data.user.username));
9
10    // create activities for later use
11    let activity_1 = Activity::new()
12        .details("this runs")
13        .state("for ten seconds")
14        .build();
15    let activity_2 = Activity::new()
16        .details("believe it")
17        .state("or not")
18        .build();
19    let close_activity = Activity::new()
20        .details("closing presence in...")
21        .duration(Duration::from_secs(5))
22        .build();
23
24    // first run
25    client.run(true).unwrap();
26
27    client.set_activity(activity_1).unwrap();
28    sleep(Duration::from_secs(5));
29    client.set_activity(activity_2).unwrap();
30    sleep(Duration::from_secs(5));
31    client.set_activity(close_activity).unwrap();
32    sleep(Duration::from_secs(5));
33}
pub fn clear_activity(&self) -> Result<()>

Clears a previously set Discord Rich Presence activity.

pub fn close(&mut self) -> Result<()>

Closes the current connection if any.