Module data

Module data 

Return types for various functions and closures for filthy-rich. Most of these do not need to be imported separately as these are already supplied to you, and are clonable and can be debugged.

Structs

ActivityResponseData
Data received in response from the server after sending a SET_ACTIVITY command.
AvatarDecorationData
The data for the user’s avatar decoration.
Collectibles
The collectibles the user has, excluding Avatar Decorations and Profile Effects.
DiscordUser
Represents the Discord user that the RPC connection is present with.
NameplateData
PrimaryGuild
ReadyData
Data received from a READY event.
ServerConfigurationData
Server configuration data received from the RPC server.