PrimaryGuild

Struct PrimaryGuild 

pub struct PrimaryGuild { /* private fields */ }

Implementations

Source

impl PrimaryGuild

pub fn identity_guild_id(&self) -> Option<&str>

The ID of the user’s primary guild.

pub fn tag(&self) -> Option<&str>

The text of the user’s server tag. Limited to 4 characters.

pub fn badge(&self) -> Option<&str>

The server tag badge hash.

pub fn identity_enabled(&self) -> Option<bool>

Whether the user is displaying the primary guild’s server tag. This can be None if the system clears the identity, e.g. the server no longer supports tags. This will be false if the user manually removes their tag.