#[repr(u8)]pub enum ActivityType {
Playing = 0,
Listening = 2,
Watching = 3,
Competing = 5,
}Expand description
Enum indicating the activity type.
NOTE: Not all six types are implemented by the Discord client itself, so only the four active ones have been implemented in this enum.
Variants