ActivityResponseData

Struct ActivityResponseData 

pub struct ActivityResponseData {
    pub application_id: String,
    pub platform: String,
    pub name: String,
    pub metadata: Value,
}
Data received in response from the server after sending a SET_ACTIVITY command.

Note that this struct doesn’t fully cover the schema of the actual response since most of the fields that are found are the same as the actual activity that is sent.

Fields

application_id: Stringplatform: Stringname: Stringmetadata: Value