Core error types module for filthy-rich.
The primary error here is PresenceError which can either be PresenceClientError or PresenceRunnerError.
These two types of errors host their own subset of errors which can be applicable for many different scenarios.
Enums
- Activity
Spec Build Error - Error which happens if building a
crate::types::ActivitySpecfails viacrate::types::ActivityBuilder::build. - Disconnect
Reason - Details about why the RPC connection was lost.
- Presence
Client Error - Points to errors specifically related to
crate::PresenceClient. - Presence
Error - Core convenience error type for usage with all types of
filthy-richoperations, includingcrate::PresenceRunnerandcrate::PresenceClient. - Presence
Runner Error - Points to errors specifically related to
crate::PresenceRunner.