Module errors

Module errors 

Core error types module for filthy-rich.

The primary error here is PresenceError which can either be PresenceClientError or PresenceRunnerError. These two types of errors host their own subset of errors which can be applicable for many different scenarios.

Enums

DisconnectReason
Details about why the RPC connection was lost.
PresenceClientError
Points to errors specifically related to super::PresenceClient.
PresenceError
Core error type for using with both super::PresenceRunner and super::PresenceClient.
PresenceRunnerError
Points to errors specifically related to super::PresenceRunner.