Core error types module for filthy-rich.
The primary error here is PresenceError which can either be PresenceClientError or PresenceRunnerError.
These two types of errors host their own subset of errors which can be applicable for many different scenarios.
Enums
- Disconnect
Reason - Details about why the RPC connection was lost.
- Presence
Client Error - Points to errors specifically related to
super::PresenceClient. - Presence
Error - Core error type for using with both
super::PresenceRunnerandsuper::PresenceClient. - Presence
Runner Error - Points to errors specifically related to
super::PresenceRunner.