Return types for various functions and closures for filthy-rich. Most of these do not need to be imported separately as these are already supplied to you, and are clonable and can be debugged.
Structs
- Activity
Response Data - Data received in response from the server after sending a SET_ACTIVITY command.
- Avatar
Decoration Data - The data for the user’s avatar decoration.
- Collectibles
- The collectibles the user has, excluding Avatar Decorations and Profile Effects.
- Discord
User - Represents the Discord user that the RPC connection is present with.
- Nameplate
Data - Primary
Guild - Ready
Data - Data received from a READY event.
- Server
Configuration Data - Server configuration data received from the RPC server.