pub struct PrimaryGuild { /* private fields */ }Implementations
Sourceimpl PrimaryGuild
impl PrimaryGuild
Sourcepub fn identity_guild_id(&self) -> Option<&str>
pub fn identity_guild_id(&self) -> Option<&str>
The ID of the user’s primary guild.
Sourcepub fn identity_enabled(&self) -> Option<bool>
pub fn identity_enabled(&self) -> Option<bool>
Whether the user is displaying the primary guild’s server tag.
This can be None if the system clears the identity, e.g. the server no longer supports tags.
This will be false if the user manually removes their tag.