pub struct ActivityResponseData {
pub application_id: String,
pub platform: String,
pub name: String,
pub metadata: Value,
}Expand description
Data received in response from the server after sending a SET_ACTIVITY command.
Note that this struct doesn’t fully cover the schema of the actual response since most of the fields that are found are the same as the actual activity that is sent.
Fields
application_id: Stringplatform: Stringname: Stringmetadata: ValueTrait Implementations
Sourceimpl Clone for ActivityResponseData
impl Clone for ActivityResponseData
Sourcefn clone(&self) -> ActivityResponseData
fn clone(&self) -> ActivityResponseData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActivityResponseData
impl Debug for ActivityResponseData
Sourceimpl<'de> Deserialize<'de> for ActivityResponseData
impl<'de> Deserialize<'de> for ActivityResponseData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more